@@ -1,15 +1,13 @@
-#!/usr/bin/env python
-
 """ MultiQC module to parse output from Cutadapt """
 
-from __future__ import print_function
-from collections import OrderedDict
-from distutils.version import StrictVersion
+
 import logging
 import re
+from collections import OrderedDict
+from distutils.version import StrictVersion
 
-from multiqc.plots import bargraph, linegraph
 from multiqc.modules.base_module import BaseMultiqcModule
+from multiqc.plots import bargraph, linegraph
 
 # Initialise the logger
 log = logging.getLogger(__name__)
