@@ -1,14 +1,11 @@
-#!/usr/bin/env python
-from __future__ import print_function
-
+import logging
 import re
 from collections import OrderedDict, defaultdict
+
 from multiqc.modules.base_module import BaseMultiqcModule
 from multiqc.plots import linegraph
 
 # Initialise the logger
-import logging
-
 log = logging.getLogger(__name__)
 
 
@@ -16,8 +13,8 @@ class DragenCoveragePerContig(BaseMultiqcModule):
     def add_coverage_per_contig(self):
         perchrom_data_by_phenotype_by_sample = defaultdict(dict)
 
-        for f in self.find_log_files("dragen/contig_mean_cov"):
-            s_name, perchrom_data_by_phenotype = parse_contig_mean_cov(f)
+        for f in self.find_log_files("dragen/wgs_contig_mean_cov"):
+            s_name, perchrom_data_by_phenotype = parse_wgs_contig_mean_cov(f)
             s_name = self.clean_s_name(s_name, f)
             if s_name in perchrom_data_by_phenotype_by_sample:
                 log.debug(f"Duplicate sample name found! Overwriting: {s_name}")
@@ -93,7 +90,7 @@ class DragenCoveragePerContig(BaseMultiqcModule):
         return perchrom_data_by_sample.keys()
 
 
-def parse_contig_mean_cov(f):
+def parse_wgs_contig_mean_cov(f):
     """
     The Contig Mean Coverage report generates a _contig_mean_cov.csv file, which contains the estimated coverage for
     all contigs, and an autosomal estimated coverage. The file includes the following three columns
@@ -106,7 +103,6 @@ def parse_contig_mean_cov(f):
 
     T_SRR7890936_50pc.wgs_contig_mean_cov_normal.csv
     T_SRR7890936_50pc.wgs_contig_mean_cov_tumor.csv
-    T_SRR7890936_50pc.target_bed_contig_mean_cov.csv
 
     chr1,11292297134,48.9945
     chr10,6482885699,48.6473
@@ -155,12 +151,18 @@ def parse_contig_mean_cov(f):
             return 1
 
     main_contig_perchrom_data = OrderedDict(
-        sorted(main_contig_perchrom_data.items(), key=lambda key_val: chrom_order(key_val[0]))
+        sorted(
+            main_contig_perchrom_data.items(),
+            key=lambda key_val: chrom_order(key_val[0]),
+        )
     )
     other_contig_perchrom_data = OrderedDict(
-        sorted(other_contig_perchrom_data.items(), key=lambda key_val: chrom_order(key_val[0]))
+        sorted(
+            other_contig_perchrom_data.items(),
+            key=lambda key_val: chrom_order(key_val[0]),
+        )
     )
 
-    m = re.search(r"(.*)\.(\S*)_contig_mean_cov_?(\S*)?.csv", f["fn"])
+    m = re.search(r"(.*).wgs_contig_mean_cov_?(tumor|normal)?.csv", f["fn"])
     sample, phenotype = m.group(1), m.group(2)
     return sample, {phenotype: [main_contig_perchrom_data, other_contig_perchrom_data]}
