@@ -1,13 +1,10 @@
-#!/usr/bin/env python
-from __future__ import print_function
-
+import logging
 import re
 from collections import OrderedDict, defaultdict
+
 from multiqc.modules.base_module import BaseMultiqcModule
 
 # Initialise the logger
-import logging
-
 log = logging.getLogger(__name__)
 
 
