@@ -1,15 +1,12 @@
-#!/usr/bin/env python
-from __future__ import print_function
-
+import logging
 import re
+
 from multiqc.modules.base_module import BaseMultiqcModule
 from multiqc.plots import table
 
-from .utils import make_headers, Metric, exist_and_number
+from .utils import Metric, exist_and_number, make_headers
 
 # Initialise the logger
-import logging
-
 log = logging.getLogger(__name__)
 
 
