@@ -1,15 +1,16 @@
-#!/usr/bin/env python
 """ MultiQC module to parse output from GATK """
-from __future__ import print_function
-from collections import OrderedDict
+
+
 import logging
+from collections import OrderedDict
 
 from multiqc.modules.base_module import BaseMultiqcModule
 
+from .base_recalibrator import BaseRecalibratorMixin
+
 # Import the GATK submodules
 # import varianteval
 from .varianteval import VariantEvalMixin
-from .base_recalibrator import BaseRecalibratorMixin
 
 # Initialise the logger
 log = logging.getLogger(__name__)
