@@ -1,14 +1,10 @@
-#!/usr/bin/env python
-
 """ MultiQC module to parse output from gffcompare """
 
-from __future__ import print_function
-import logging
-import os
-from collections import OrderedDict
 
-from multiqc.plots import scatter, bargraph
+import logging
+
 from multiqc.modules.base_module import BaseMultiqcModule
+from multiqc.plots import bargraph, scatter
 
 # Initialise the logger
 log = logging.getLogger(__name__)
