@@ -1,13 +1,12 @@
 """ MultiQC module to parse output from HOPS postprocessing script """
 
-from __future__ import print_function
-from collections import OrderedDict
-import logging
-import json
 
+import json
+import logging
+
+from multiqc.modules.base_module import BaseMultiqcModule
 from multiqc.plots import heatmap
 from multiqc.utils import config
-from multiqc.modules.base_module import BaseMultiqcModule
 
 log = logging.getLogger(__name__)
 
