@@ -1,8 +1,6 @@
-#!/usr/bin/env python
-
 """ MultiQC module to parse output from leeHom """
 
-from __future__ import print_function
+
 import logging
 import re
 
