@@ -1,15 +1,13 @@
-#!/usr/bin/env python
-
 """ MultiQC module to parse output from methylQA """
 
-from __future__ import print_function
-from collections import OrderedDict
+
 import logging
 import os
 import re
+from collections import OrderedDict
 
-from multiqc.plots import linegraph
 from multiqc.modules.base_module import BaseMultiqcModule
+from multiqc.plots import linegraph
 
 # Initialise the logger
 log = logging.getLogger(__name__)
@@ -25,6 +23,7 @@ class MultiqcModule(BaseMultiqcModule):
             target="methylQA",
             href="http://methylqa.sourceforge.net/",
             info=" - a methylation sequencing data quality assessment tool.",
+            doi="10.1016/j.ymeth.2014.10.032",
         )
 
         # Find and load any methylQA reports
