@@ -1,17 +1,16 @@
 """ MultiQC module to parse output from mosdepth """
 
-from __future__ import print_function
 
-from collections import defaultdict, OrderedDict
-import logging
 import fnmatch
+import logging
+from collections import OrderedDict, defaultdict
 
 from multiqc import config
 from multiqc.modules.base_module import BaseMultiqcModule
 
 # Initialise the logger
 from multiqc.modules.qualimap.QM_BamQC import coverage_histogram_helptext, genome_fraction_helptext
-from multiqc.plots import linegraph, bargraph
+from multiqc.plots import bargraph, linegraph
 
 log = logging.getLogger(__name__)
 
@@ -296,8 +295,6 @@ class MultiqcModule(BaseMultiqcModule):
             for t in threshs:
                 if int(t) in dist_subset:
                     genstats[s_name][f"{t}_x_pc"] = dist_subset[t]
-                else:
-                    genstats[s_name][f"{t}_x_pc"] = 0
 
         for t in threshs:
             genstats_headers[f"{t}_x_pc"] = {
