@@ -1,14 +1,11 @@
-#!/usr/bin/env python
-
 """ MultiQC submodule to parse output from Picard QualityYieldMetrics """
 
-from collections import OrderedDict, defaultdict
 import logging
-import os
-import re
+from collections import OrderedDict
 
 from multiqc import config
-from multiqc.plots import table, linegraph
+from multiqc.plots import linegraph, table
+
 from .util import read_sample_name
 
 # Initialise the logger
@@ -40,6 +37,8 @@ def parse_reports(self):
 
     # Go through logs and find Metrics
     for f in self.find_log_files("picard/quality_yield_metrics", filehandles=True):
+        self.add_data_source(f, section="QualityYieldMetrics")
+
         parsed_data = dict()
         s_name = None
         keys = None
