@@ -1,14 +1,11 @@
-#!/usr/bin/env python
-
 """ MultiQC module to parse output from pychopper """
 
-from __future__ import print_function
+
 import logging
-import os
 from collections import OrderedDict
 
-from multiqc.plots import linegraph, bargraph
 from multiqc.modules.base_module import BaseMultiqcModule
+from multiqc.plots import bargraph, linegraph
 
 # Initialise the logger
 log = logging.getLogger(__name__)
