@@ -1,15 +1,13 @@
-#!/usr/bin/env python
-
 """ MultiQC module to parse output from Salmon """
 
-from __future__ import print_function
-from collections import OrderedDict
+
 import json
 import logging
 import os
+from collections import OrderedDict
 
-from multiqc.plots import linegraph
 from multiqc.modules.base_module import BaseMultiqcModule
+from multiqc.plots import linegraph
 
 # Initialise the logger
 log = logging.getLogger(__name__)
