@@ -1,14 +1,13 @@
-#!/usr/bin/env python
-
 """ MultiQC module to parse output from Samblaster """
 
-from __future__ import print_function
-import os
-from collections import OrderedDict
+
 import logging
+import os
 import re
-from multiqc.plots import bargraph
+from collections import OrderedDict
+
 from multiqc.modules.base_module import BaseMultiqcModule
+from multiqc.plots import bargraph
 
 # Initialise the logger
 log = logging.getLogger(__name__)
