@@ -1,14 +1,12 @@
-#!/usr/bin/env python
-
 """ MultiQC module to parse logs from Skewer """
 
-from __future__ import print_function
 
-from collections import OrderedDict
 import logging
 import re
-from multiqc.plots import linegraph
+from collections import OrderedDict
+
 from multiqc.modules.base_module import BaseMultiqcModule
+from multiqc.plots import linegraph
 
 # Initialise the logger
 log = logging.getLogger(__name__)
