@@ -1,13 +1,11 @@
-#!/usr/bin/env python
-
 """ MultiQC module to parse logs from SnpEff """
 
-from __future__ import print_function
 
-from collections import OrderedDict
 import logging
-from multiqc.plots import bargraph, linegraph
+from collections import OrderedDict
+
 from multiqc.modules.base_module import BaseMultiqcModule
+from multiqc.plots import bargraph, linegraph
 
 # Initialise the logger
 log = logging.getLogger(__name__)
