@@ -1,10 +1,10 @@
-#!/usr/bin/env python
-
 """ MultiQC module to parse output from vcftools """
 
-from __future__ import print_function
+
 import logging
+
 from multiqc.modules.base_module import BaseMultiqcModule
+
 from .relatedness2 import Relatedness2Mixin
 from .tstv_by_count import TsTvByCountMixin
 from .tstv_by_qual import TsTvByQualMixin
@@ -21,6 +21,7 @@ class MultiqcModule(BaseMultiqcModule, Relatedness2Mixin, TsTvByCountMixin, TsTv
             anchor="vcftools",
             href="https://vcftools.github.io",
             info="is a program for working with and reporting on VCF files.",
+            doi="10.1093/bioinformatics/btr330",
         )
 
         n = dict()
