@@ -1,13 +1,12 @@
-#!/usr/bin/env python
-
 """ MultiQC module to parse output from VerifyBAMID """
 
-from __future__ import print_function
-from collections import OrderedDict
+
 import logging
+from collections import OrderedDict
+
 from multiqc import config
-from multiqc.plots import table
 from multiqc.modules.base_module import BaseMultiqcModule
+from multiqc.plots import table
 
 # Initialise the logger
 log = logging.getLogger(__name__)
