@@ -10,5 +10,5 @@ module.
 import os
 
 template_dir = os.path.dirname(__file__)
-template_parent = 'default'
-base_fn = 'base.html'
+template_parent = "default"
+base_fn = "base.html"
